@@ -12,7 +12,7 @@ import os.path as op
 from os import makedirs, symlink
 from flask import Flask
 from flask.ext.flatpages import FlatPages
-from flask.ext.pagedown import PageDown
+from flask.ext.codemirror import CodeMirror
 from flask.ext.login import LoginManager
 from flask.ext.babel import Babel
 from flask.ext.themes2 import Themes
@@ -41,9 +41,6 @@ if not op.exists(path) :
 # flatpages
 pages = FlatPages(app)
 
-# pagedown
-pagedown = PageDown(app)
-
 # login
 lm = LoginManager()
 lm.init_app(app)
@@ -55,6 +52,9 @@ babel = Babel(app)
 # themes support
 Themes(app, app_identifier = 'microbe')
 
+# codemirror
+codemirror = CodeMirror(app)
+
 # blueprint
 from admin import bp as admin_module
 from admin import load_user
